//importing Timer libary
#include "MillisTimer.h"
//setting up pin references 
#define BUTTON_PIN 4
#define POTENTIOMETER_PIN1 A1
#define POTENTIOMETER_PIN2 A2
#define PUMPSWITCH_PIN1 9
#define PUMPSWITCH_PIN2 10
//The time in miliseconds that it takes for one pump to move 300 ml
const long int maxtime = 225000;//in miliseconds
//Creating the timer objects
MillisTimer timer1 = MillisTimer(90000);
MillisTimer timer2 = MillisTimer(90000);

void setup() {
  Serial.begin(31250);
  //setting the pin modes of the pins
  pinMode(PUMPSWITCH_PIN1,OUTPUT);
  pinMode(PUMPSWITCH_PIN2,OUTPUT);
  pinMode(BUTTON_PIN,INPUT_PULLUP);
  pinMode(POTENTIOMETER_PIN1,INPUT);
  pinMode(POTENTIOMETER_PIN2,INPUT);
  
  //I needed to have my pins set to HIGH for the relay to not run pumps.
  digitalWrite(PUMPSWITCH_PIN1,HIGH);
  digitalWrite(PUMPSWITCH_PIN2,HIGH); 

  //setting the timers to only run once. Default they are set to 0 which means repeat infinitely
  timer1.setRepeats(1);
  timer2.setRepeats(1);
}

void loop() {
  //telling the timers to run if they have been started
  timer1.run();
  timer2.run();

  //checking if the timer is running and setting the pins accordingly 
  if(timer1.isRunning()){
    digitalWrite(PUMPSWITCH_PIN1,LOW); //runs the pump
  } else{
    digitalWrite(PUMPSWITCH_PIN1,HIGH); //stops the pump
  }
  if(timer2.isRunning()){
    digitalWrite(PUMPSWITCH_PIN2,LOW); //runs the pump
  }else{
    digitalWrite(PUMPSWITCH_PIN2,HIGH); //stops the pump  
  }

  //checking if a timer is running
  if(timer1.isRunning() || timer2.isRunning()){
  } else{
    //checking if the button is pressed when no timer is running
    int a = digitalRead(BUTTON_PIN);
    if(a == 0){
      //reading the potentiometers
      int inputsensor1 = analogRead(POTENTIOMETER_PIN1);
      int inputsensor2 = analogRead(POTENTIOMETER_PIN2);
      //Remaping the value to a milisecond time.
      long int time1 = map(inputsensor1, 0, 1023, 0, maxtime);
      long int time2 = map(inputsensor2, 0, 1023, 0, maxtime);
      //setting the timers to the new time.
      timer1.setInterval(time1);
      timer2.setInterval(time2);
      //starting the timers so that they can run when called
      timer1.start();
      timer2.start();
   }  
  }
}
